View Source Hyperliquid.Api.Exchange.ScheduleCancel (hyperliquid v0.2.2)

Schedule all open orders to be cancelled at a specified time.

See: https://hyperliquid.gitbook.io/hyperliquid-docs/for-developers/api/exchange-endpoint

Summary

Functions

Schedule all open orders to be cancelled at a specified time.

Functions

Link to this function

request(time, opts \\ [])

Schedule all open orders to be cancelled at a specified time.

Parameters

  • private_key: Private key for signing (hex string)
  • time: Unix timestamp in milliseconds when to cancel orders (or nil to remove scheduled cancel)
  • opts: Optional parameters

Options

  • :vault_address - Schedule for a vault

Returns

  • {:ok, response} - Schedule result
  • {:error, term()} - Error details

Examples

# Schedule cancel in 1 hour
{:ok, result} = ScheduleCancel.request(private_key, System.system_time(:millisecond) + 3600000)

# Remove scheduled cancel
{:ok, result} = ScheduleCancel.request(private_key, nil)