View Source Hyperliquid.Api.Info (hyperliquid v0.2.2)

Convenience functions for Info API endpoints.

This module provides snake_case wrapper functions that delegate to the underlying endpoint modules, improving developer ergonomics.

Usage

# Direct endpoint call (still supported)
{:ok, mids} = Hyperliquid.Api.Info.AllMids.request()

# Convenience wrapper (new)
{:ok, mids} = Hyperliquid.Api.Info.all_mids()

# With parameters
{:ok, book} = Hyperliquid.Api.Info.l2_book("BTC")
{:ok, state} = Hyperliquid.Api.Info.clearinghouse_state("0xabc...")

Available Functions

All Info endpoints are available as snake_case functions. Each endpoint provides both safe and bang variants:

  • endpoint_name(...) - Returns {:ok, result} or {:error, reason}
  • endpoint_name!(...) - Returns result or raises on error

For endpoints with storage enabled, additional fetch_* variants are available:

  • fetch_endpoint_name(...) - Request and persist to storage backends

See Hyperliquid.Api.Registry.list_by_type(:info) for all available endpoints.

Summary

Functions

Retrieve active trading data for a specific asset and user

Retrieve active trading data for a specific asset and user (bang variant)

Retrieve information about aligned quote tokens

Retrieve information about aligned quote tokens (bang variant)

Retrieve borrow/lend reserve states

Retrieve borrow/lend reserve states (bang variant)

Retrieve mid prices for all actively traded coins

Retrieve mid prices for all actively traded coins (bang variant)

Retrieve metadata for perpetual assets across all or a specific DEX

Retrieve metadata for perpetual assets across all or a specific DEX (bang variant)

Retrieve OHLCV candle data for a coin

Retrieve OHLCV candle data for a coin (bang variant)

Retrieve a user's perpetuals account summary

Retrieve a user's perpetuals account summary (bang variant)

Retrieve user's staking delegations

Retrieve user's staking delegations (bang variant)

Retrieve history of user's delegation actions

Retrieve history of user's delegation actions (bang variant)

Retrieve user's staking rewards history

Retrieve user's staking rewards history (bang variant)

Retrieve summary of user's delegation status

Retrieve summary of user's delegation status (bang variant)

Retrieve exchange operational status

Retrieve exchange operational status (bang variant)

Retrieve extra agents authorized by a user

Retrieve extra agents authorized by a user (bang variant)

Retrieve metadata for perpetual assets across all or a specific DEX

Retrieve metadata for perpetual assets across all or a specific DEX (fetch bang variant)

Retrieve OHLCV candle data for a coin

Retrieve OHLCV candle data for a coin (fetch bang variant)

Retrieve a user's perpetuals account summary

Retrieve a user's perpetuals account summary (fetch bang variant)

Retrieve historical orders for a user

Retrieve historical orders for a user (fetch bang variant)

Retrieve margin table details

Retrieve margin table details (fetch bang variant)

Retrieve a user's open orders

Retrieve a user's open orders (fetch bang variant)

Query order status by OID or CLOID

Query order status by OID or CLOID (fetch bang variant)

Retrieve all perpetual DEXs

Retrieve all perpetual DEXs (fetch bang variant)

Retrieve recent trades for a coin

Retrieve recent trades for a coin (fetch bang variant)

Retrieve a user's spot token balances

Retrieve a user's spot token balances (fetch bang variant)

Retrieve spot asset metadata

Retrieve spot asset metadata (fetch bang variant)

Retrieve token details

Retrieve token details (fetch bang variant)

Retrieve a user's trade fills

Retrieve a user's trade fills (fetch bang variant)

Retrieve user's trade fills filtered by time range

Retrieve user's trade fills filtered by time range (fetch bang variant)

Retrieve user's TWAP slice fills

Retrieve user's TWAP slice fills (fetch bang variant)

Retrieve user's TWAP slice fills filtered by time

Retrieve user's TWAP slice fills filtered by time (fetch bang variant)

Retrieve open orders with frontend display information

Retrieve open orders with frontend display information (bang variant)

Retrieve historical funding rates for an asset

Retrieve historical funding rates for an asset (bang variant)

Retrieve gossip network root IP addresses

Retrieve gossip network root IP addresses (bang variant)

Retrieve historical orders for a user

Retrieve historical orders for a user (bang variant)

Check VIP status for a user

Check VIP status for a user (bang variant)

Retrieve L2 order book snapshot for a coin

Retrieve L2 order book snapshot for a coin (bang variant)

Retrieve leading vaults information

Retrieve leading vaults information (bang variant)

Check legal/compliance status for a user

Check legal/compliance status for a user (bang variant)

Retrieve liquidatable positions

Retrieve liquidatable positions (bang variant)

Retrieve margin table details

Retrieve margin table details (bang variant)

Retrieve maximum builder fee for a user

Retrieve maximum builder fee for a user (bang variant)

Retrieve maximum market order notional values

Retrieve maximum market order notional values (bang variant)

Retrieve perpetuals metadata (universe and margin tables)

Retrieve perpetuals metadata (universe and margin tables) (bang variant)

Retrieve perpetuals metadata and asset contexts

Retrieve perpetuals metadata and asset contexts (bang variant)

Retrieve a user's open orders

Retrieve a user's open orders (bang variant)

Query order status by OID or CLOID

Query order status by OID or CLOID (bang variant)

Retrieve perpetual deployment auction status

Retrieve perpetual deployment auction status (bang variant)

Retrieve perpetual DEX limits

Retrieve perpetual DEX limits (bang variant)

Retrieve all perpetual DEXs

Retrieve all perpetual DEXs (bang variant)

Retrieve perpetuals at open interest cap

Retrieve perpetuals at open interest cap (bang variant)

Retrieve user portfolio performance data

Retrieve user portfolio performance data (bang variant)

Check user existence before transfer

Check user existence before transfer (bang variant)

Retrieve predicted funding rates for perpetuals

Retrieve predicted funding rates for perpetuals (bang variant)

Retrieve recent trades for a coin

Retrieve recent trades for a coin (bang variant)

Retrieve referral information for a user

Retrieve referral information for a user (bang variant)

Retrieve a user's spot token balances

Retrieve a user's spot token balances (bang variant)

Retrieve spot token deployment state for user

Retrieve spot token deployment state for user (bang variant)

Retrieve spot asset metadata

Retrieve spot asset metadata (bang variant)

Retrieve spot metadata and asset contexts

Retrieve spot metadata and asset contexts (bang variant)

Retrieve spot pair deployment auction status

Retrieve spot pair deployment auction status (bang variant)

Retrieve extended sub-accounts information

Retrieve extended sub-accounts information (bang variant)

Retrieve user's sub-accounts

Retrieve user's sub-accounts (bang variant)

Retrieve token details

Retrieve token details (bang variant)

Retrieve user's TWAP order history

Retrieve user's TWAP order history (bang variant)

Retrieve user DEX abstraction settings

Retrieve user DEX abstraction settings (bang variant)

Retrieve user's trading fee rates

Retrieve user's trading fee rates (bang variant)

Retrieve a user's trade fills

Retrieve a user's trade fills (bang variant)

Retrieve user's trade fills filtered by time range

Retrieve user's trade fills filtered by time range (bang variant)

Retrieve user's non-funding ledger updates

Retrieve user's non-funding ledger updates (bang variant)

Query user rate limit status

Query user rate limit status (bang variant)

Retrieve user role information

Retrieve user role information (bang variant)

Retrieve multi-sig signers for a user

Retrieve multi-sig signers for a user (bang variant)

Retrieve user's TWAP slice fills

Retrieve user's TWAP slice fills (bang variant)

Retrieve user's TWAP slice fills filtered by time

Retrieve user's TWAP slice fills filtered by time (bang variant)

Retrieve user's vault equity positions

Retrieve user's vault equity positions (bang variant)

Retrieve validator L1 voting information

Retrieve validator L1 voting information (bang variant)

Retrieve validator summaries

Retrieve validator summaries (bang variant)

Retrieve detailed vault information

Retrieve detailed vault information (bang variant)

Retrieve vault summaries

Retrieve vault summaries (bang variant)

Functions

Link to this function

active_asset_data(user, coin)

@spec active_asset_data(term(), term()) :: {:ok, struct()} | {:error, term()}

Retrieve active trading data for a specific asset and user

Delegates to Hyperliquid.Api.Info.ActiveAssetData.request/2.

Parameters

  • user - Required parameter
  • coin - Required parameter

Returns

Leverage, max trade sizes, available balance, and mark price

Link to this function

active_asset_data!(user, coin)

@spec active_asset_data!(term(), term()) :: struct()

Retrieve active trading data for a specific asset and user (bang variant)

Delegates to Hyperliquid.Api.Info.ActiveAssetData.request!/2.

Raises on error.

Link to this function

aligned_quote_token_info(token)

@spec aligned_quote_token_info(term()) :: {:ok, struct()} | {:error, term()}

Retrieve information about aligned quote tokens

Delegates to Hyperliquid.Api.Info.AlignedQuoteTokenInfo.request/1.

Parameters

  • token - Required parameter

Returns

Alignment status, mint supply, and predicted rates

Link to this function

aligned_quote_token_info!(token)

@spec aligned_quote_token_info!(term()) :: struct()

Retrieve information about aligned quote tokens (bang variant)

Delegates to Hyperliquid.Api.Info.AlignedQuoteTokenInfo.request!/1.

Raises on error.

Link to this function

all_borrow_lend_reserve_states()

@spec all_borrow_lend_reserve_states() :: {:ok, struct()} | {:error, term()}

Retrieve borrow/lend reserve states

Delegates to Hyperliquid.Api.Info.AllBorrowLendReserveStates.request/0.

Returns

Reserve states with rates, balances, and utilization

Examples

{:ok, result} = all_borrow_lend_reserve_states()
Link to this function

all_borrow_lend_reserve_states!()

@spec all_borrow_lend_reserve_states!() :: struct()

Retrieve borrow/lend reserve states (bang variant)

Delegates to Hyperliquid.Api.Info.AllBorrowLendReserveStates.request!/0.

Raises on error.

@spec all_mids(keyword()) :: {:ok, struct()} | {:error, term()}

Retrieve mid prices for all actively traded coins

Delegates to Hyperliquid.Api.Info.AllMids.request/1.

Parameters

  • opts - Optional parameters: [:dex]

Returns

Map of coin symbols to mid prices as strings

@spec all_mids!(keyword()) :: struct()

Retrieve mid prices for all actively traded coins (bang variant)

Delegates to Hyperliquid.Api.Info.AllMids.request!/1.

Raises on error.

@spec all_perp_metas() :: {:ok, struct()} | {:error, term()}

Retrieve metadata for perpetual assets across all or a specific DEX

Delegates to Hyperliquid.Api.Info.AllPerpMetas.request/0.

Returns

Universe of perp assets with margin tables and collateral token

Examples

{:ok, result} = all_perp_metas()
@spec all_perp_metas!() :: struct()

Retrieve metadata for perpetual assets across all or a specific DEX (bang variant)

Delegates to Hyperliquid.Api.Info.AllPerpMetas.request!/0.

Raises on error.

Link to this function

candle_snapshot(coin, interval, start_time, end_time)

@spec candle_snapshot(term(), term(), term(), term()) ::
  {:ok, struct()} | {:error, term()}

Retrieve OHLCV candle data for a coin

Delegates to Hyperliquid.Api.Info.CandleSnapshot.request/4.

Parameters

  • coin - Required parameter
  • interval - Required parameter
  • start_time - Required parameter
  • end_time - Required parameter

Returns

Array of candles with OHLCV data and trade counts

Link to this function

candle_snapshot!(coin, interval, start_time, end_time)

@spec candle_snapshot!(term(), term(), term(), term()) :: struct()

Retrieve OHLCV candle data for a coin (bang variant)

Delegates to Hyperliquid.Api.Info.CandleSnapshot.request!/4.

Raises on error.

Link to this function

clearinghouse_state(user)

@spec clearinghouse_state(term()) :: {:ok, struct()} | {:error, term()}

Retrieve a user's perpetuals account summary

Delegates to Hyperliquid.Api.Info.ClearinghouseState.request/1.

Parameters

  • user - Required parameter

Returns

Clearinghouse state with margin summary and positions

Link to this function

clearinghouse_state!(user)

@spec clearinghouse_state!(term()) :: struct()

Retrieve a user's perpetuals account summary (bang variant)

Delegates to Hyperliquid.Api.Info.ClearinghouseState.request!/1.

Raises on error.

@spec delegations(term()) :: {:ok, struct()} | {:error, term()}

Retrieve user's staking delegations

Delegates to Hyperliquid.Api.Info.Delegations.request/1.

Parameters

  • user - Required parameter

Returns

List of validators user has delegated to with amounts and lock times

@spec delegations!(term()) :: struct()

Retrieve user's staking delegations (bang variant)

Delegates to Hyperliquid.Api.Info.Delegations.request!/1.

Raises on error.

@spec delegator_history(term()) :: {:ok, struct()} | {:error, term()}

Retrieve history of user's delegation actions

Delegates to Hyperliquid.Api.Info.DelegatorHistory.request/1.

Parameters

  • user - Required parameter

Returns

Delegation and undelegation events with timestamps and transaction hashes

Link to this function

delegator_history!(user)

@spec delegator_history!(term()) :: struct()

Retrieve history of user's delegation actions (bang variant)

Delegates to Hyperliquid.Api.Info.DelegatorHistory.request!/1.

Raises on error.

@spec delegator_rewards(term()) :: {:ok, struct()} | {:error, term()}

Retrieve user's staking rewards history

Delegates to Hyperliquid.Api.Info.DelegatorRewards.request/1.

Parameters

  • user - Required parameter

Returns

Delegation and commission rewards with timestamps

Link to this function

delegator_rewards!(user)

@spec delegator_rewards!(term()) :: struct()

Retrieve user's staking rewards history (bang variant)

Delegates to Hyperliquid.Api.Info.DelegatorRewards.request!/1.

Raises on error.

@spec delegator_summary(term()) :: {:ok, struct()} | {:error, term()}

Retrieve summary of user's delegation status

Delegates to Hyperliquid.Api.Info.DelegatorSummary.request/1.

Parameters

  • user - Required parameter

Returns

Totals for delegated, undelegated, and pending withdrawal amounts

Link to this function

delegator_summary!(user)

@spec delegator_summary!(term()) :: struct()

Retrieve summary of user's delegation status (bang variant)

Delegates to Hyperliquid.Api.Info.DelegatorSummary.request!/1.

Raises on error.

@spec exchange_status() :: {:ok, struct()} | {:error, term()}

Retrieve exchange operational status

Delegates to Hyperliquid.Api.Info.ExchangeStatus.request/0.

Returns

Status object with maintenance mode and block height

Examples

{:ok, result} = exchange_status()
@spec exchange_status!() :: struct()

Retrieve exchange operational status (bang variant)

Delegates to Hyperliquid.Api.Info.ExchangeStatus.request!/0.

Raises on error.

@spec extra_agents(term()) :: {:ok, struct()} | {:error, term()}

Retrieve extra agents authorized by a user

Delegates to Hyperliquid.Api.Info.ExtraAgents.request/1.

Parameters

  • user - Required parameter

Returns

List of additional agents with addresses, names, and validity periods

@spec extra_agents!(term()) :: struct()

Retrieve extra agents authorized by a user (bang variant)

Delegates to Hyperliquid.Api.Info.ExtraAgents.request!/1.

Raises on error.

@spec fetch_all_perp_metas() :: {:ok, struct()} | {:error, term()}

Retrieve metadata for perpetual assets across all or a specific DEX

Fetches data and persists to configured storage backends.

Delegates to Hyperliquid.Api.Info.AllPerpMetas.fetch/0.

@spec fetch_all_perp_metas!() :: struct()

Retrieve metadata for perpetual assets across all or a specific DEX (fetch bang variant)

Fetches data, persists to storage, and raises on error.

Delegates to Hyperliquid.Api.Info.AllPerpMetas.fetch!/0.

Link to this function

fetch_candle_snapshot(coin, interval, start_time, end_time)

@spec fetch_candle_snapshot(term(), term(), term(), term()) ::
  {:ok, struct()} | {:error, term()}

Retrieve OHLCV candle data for a coin

Fetches data and persists to configured storage backends.

Delegates to Hyperliquid.Api.Info.CandleSnapshot.fetch/4.

Link to this function

fetch_candle_snapshot!(coin, interval, start_time, end_time)

@spec fetch_candle_snapshot!(term(), term(), term(), term()) :: struct()

Retrieve OHLCV candle data for a coin (fetch bang variant)

Delegates to Hyperliquid.Api.Info.CandleSnapshot.fetch!/4.

Link to this function

fetch_clearinghouse_state(user)

@spec fetch_clearinghouse_state(term()) :: {:ok, struct()} | {:error, term()}

Retrieve a user's perpetuals account summary

Fetches data and persists to configured storage backends.

Delegates to Hyperliquid.Api.Info.ClearinghouseState.fetch/1.

Link to this function

fetch_clearinghouse_state!(user)

@spec fetch_clearinghouse_state!(term()) :: struct()

Retrieve a user's perpetuals account summary (fetch bang variant)

Delegates to Hyperliquid.Api.Info.ClearinghouseState.fetch!/1.

Link to this function

fetch_historical_orders(user)

@spec fetch_historical_orders(term()) :: {:ok, struct()} | {:error, term()}

Retrieve historical orders for a user

Fetches data and persists to configured storage backends.

Delegates to Hyperliquid.Api.Info.HistoricalOrders.fetch/1.

Link to this function

fetch_historical_orders!(user)

@spec fetch_historical_orders!(term()) :: struct()

Retrieve historical orders for a user (fetch bang variant)

Delegates to Hyperliquid.Api.Info.HistoricalOrders.fetch!/1.

@spec fetch_margin_table(term()) :: {:ok, struct()} | {:error, term()}

Retrieve margin table details

Fetches data and persists to configured storage backends.

Delegates to Hyperliquid.Api.Info.MarginTable.fetch/1.

@spec fetch_margin_table!(term()) :: struct()

Retrieve margin table details (fetch bang variant)

Delegates to Hyperliquid.Api.Info.MarginTable.fetch!/1.

@spec fetch_open_orders(term()) :: {:ok, struct()} | {:error, term()}

Retrieve a user's open orders

Fetches data and persists to configured storage backends.

Delegates to Hyperliquid.Api.Info.OpenOrders.fetch/1.

Link to this function

fetch_open_orders!(user)

@spec fetch_open_orders!(term()) :: struct()

Retrieve a user's open orders (fetch bang variant)

Delegates to Hyperliquid.Api.Info.OpenOrders.fetch!/1.

Link to this function

fetch_order_status(user, oid)

@spec fetch_order_status(term(), term()) :: {:ok, struct()} | {:error, term()}

Query order status by OID or CLOID

Fetches data and persists to configured storage backends.

Delegates to Hyperliquid.Api.Info.OrderStatus.fetch/2.

Link to this function

fetch_order_status!(user, oid)

@spec fetch_order_status!(term(), term()) :: struct()

Query order status by OID or CLOID (fetch bang variant)

Delegates to Hyperliquid.Api.Info.OrderStatus.fetch!/2.

@spec fetch_perp_dexs() :: {:ok, struct()} | {:error, term()}

Retrieve all perpetual DEXs

Fetches data and persists to configured storage backends.

Delegates to Hyperliquid.Api.Info.PerpDexs.fetch/0.

@spec fetch_perp_dexs!() :: struct()

Retrieve all perpetual DEXs (fetch bang variant)

Fetches data, persists to storage, and raises on error.

Delegates to Hyperliquid.Api.Info.PerpDexs.fetch!/0.

Link to this function

fetch_recent_trades(coin)

@spec fetch_recent_trades(term()) :: {:ok, struct()} | {:error, term()}

Retrieve recent trades for a coin

Fetches data and persists to configured storage backends.

Delegates to Hyperliquid.Api.Info.RecentTrades.fetch/1.

Link to this function

fetch_recent_trades!(coin)

@spec fetch_recent_trades!(term()) :: struct()

Retrieve recent trades for a coin (fetch bang variant)

Delegates to Hyperliquid.Api.Info.RecentTrades.fetch!/1.

Link to this function

fetch_spot_clearinghouse_state(user)

@spec fetch_spot_clearinghouse_state(term()) :: {:ok, struct()} | {:error, term()}

Retrieve a user's spot token balances

Fetches data and persists to configured storage backends.

Delegates to Hyperliquid.Api.Info.SpotClearinghouseState.fetch/1.

Link to this function

fetch_spot_clearinghouse_state!(user)

@spec fetch_spot_clearinghouse_state!(term()) :: struct()

Retrieve a user's spot token balances (fetch bang variant)

Delegates to Hyperliquid.Api.Info.SpotClearinghouseState.fetch!/1.

@spec fetch_spot_meta() :: {:ok, struct()} | {:error, term()}

Retrieve spot asset metadata

Fetches data and persists to configured storage backends.

Delegates to Hyperliquid.Api.Info.SpotMeta.fetch/0.

@spec fetch_spot_meta!() :: struct()

Retrieve spot asset metadata (fetch bang variant)

Fetches data, persists to storage, and raises on error.

Delegates to Hyperliquid.Api.Info.SpotMeta.fetch!/0.

Link to this function

fetch_token_details(tokenId)

@spec fetch_token_details(term()) :: {:ok, struct()} | {:error, term()}

Retrieve token details

Fetches data and persists to configured storage backends.

Delegates to Hyperliquid.Api.Info.TokenDetails.fetch/1.

Link to this function

fetch_token_details!(tokenId)

@spec fetch_token_details!(term()) :: struct()

Retrieve token details (fetch bang variant)

Delegates to Hyperliquid.Api.Info.TokenDetails.fetch!/1.

@spec fetch_user_fills(term()) :: {:ok, struct()} | {:error, term()}

Retrieve a user's trade fills

Fetches data and persists to configured storage backends.

Delegates to Hyperliquid.Api.Info.UserFills.fetch/1.

@spec fetch_user_fills!(term()) :: struct()

Retrieve a user's trade fills (fetch bang variant)

Delegates to Hyperliquid.Api.Info.UserFills.fetch!/1.

Link to this function

fetch_user_fills_by_time(user, startTime, opts \\ [])

@spec fetch_user_fills_by_time(term(), term(), keyword()) ::
  {:ok, struct()} | {:error, term()}

Retrieve user's trade fills filtered by time range

Fetches data and persists to configured storage backends.

Delegates to Hyperliquid.Api.Info.UserFillsByTime.fetch/3.

Link to this function

fetch_user_fills_by_time!(user, startTime, opts \\ [])

@spec fetch_user_fills_by_time!(term(), term(), keyword()) :: struct()

Retrieve user's trade fills filtered by time range (fetch bang variant)

Delegates to Hyperliquid.Api.Info.UserFillsByTime.fetch!/3.

Link to this function

fetch_user_twap_slice_fills(user)

@spec fetch_user_twap_slice_fills(term()) :: {:ok, struct()} | {:error, term()}

Retrieve user's TWAP slice fills

Fetches data and persists to configured storage backends.

Delegates to Hyperliquid.Api.Info.UserTwapSliceFills.fetch/1.

Link to this function

fetch_user_twap_slice_fills!(user)

@spec fetch_user_twap_slice_fills!(term()) :: struct()

Retrieve user's TWAP slice fills (fetch bang variant)

Delegates to Hyperliquid.Api.Info.UserTwapSliceFills.fetch!/1.

Link to this function

fetch_user_twap_slice_fills_by_time(user, startTime, opts \\ [])

@spec fetch_user_twap_slice_fills_by_time(term(), term(), keyword()) ::
  {:ok, struct()} | {:error, term()}

Retrieve user's TWAP slice fills filtered by time

Fetches data and persists to configured storage backends.

Delegates to Hyperliquid.Api.Info.UserTwapSliceFillsByTime.fetch/3.

Link to this function

fetch_user_twap_slice_fills_by_time!(user, startTime, opts \\ [])

@spec fetch_user_twap_slice_fills_by_time!(term(), term(), keyword()) :: struct()

Retrieve user's TWAP slice fills filtered by time (fetch bang variant)

Delegates to Hyperliquid.Api.Info.UserTwapSliceFillsByTime.fetch!/3.

Link to this function

frontend_open_orders(user)

@spec frontend_open_orders(term()) :: {:ok, struct()} | {:error, term()}

Retrieve open orders with frontend display information

Delegates to Hyperliquid.Api.Info.FrontendOpenOrders.request/1.

Parameters

  • user - Required parameter

Returns

List of open orders with additional display fields

Link to this function

frontend_open_orders!(user)

@spec frontend_open_orders!(term()) :: struct()

Retrieve open orders with frontend display information (bang variant)

Delegates to Hyperliquid.Api.Info.FrontendOpenOrders.request!/1.

Raises on error.

Link to this function

funding_history(coin, start_time, opts \\ [])

@spec funding_history(term(), term(), keyword()) :: {:ok, struct()} | {:error, term()}

Retrieve historical funding rates for an asset

Delegates to Hyperliquid.Api.Info.FundingHistory.request/3.

Parameters

  • coin - Required parameter
  • start_time - Required parameter
  • opts - Optional parameters: [:end_time]

Returns

Historical funding rate records for a perpetual asset

Link to this function

funding_history!(coin, start_time, opts \\ [])

@spec funding_history!(term(), term(), keyword()) :: struct()

Retrieve historical funding rates for an asset (bang variant)

Delegates to Hyperliquid.Api.Info.FundingHistory.request!/3.

Raises on error.

@spec gossip_root_ips() :: {:ok, struct()} | {:error, term()}

Retrieve gossip network root IP addresses

Delegates to Hyperliquid.Api.Info.GossipRootIps.request/0.

Returns

List of root node IP addresses for the Hyperliquid gossip network

Examples

{:ok, result} = gossip_root_ips()
@spec gossip_root_ips!() :: struct()

Retrieve gossip network root IP addresses (bang variant)

Delegates to Hyperliquid.Api.Info.GossipRootIps.request!/0.

Raises on error.

@spec historical_orders(term()) :: {:ok, struct()} | {:error, term()}

Retrieve historical orders for a user

Delegates to Hyperliquid.Api.Info.HistoricalOrders.request/1.

Parameters

  • user - Required parameter

Returns

All historical orders including filled, canceled, and rejected orders

Link to this function

historical_orders!(user)

@spec historical_orders!(term()) :: struct()

Retrieve historical orders for a user (bang variant)

Delegates to Hyperliquid.Api.Info.HistoricalOrders.request!/1.

Raises on error.

@spec is_vip(term()) :: {:ok, struct()} | {:error, term()}

Check VIP status for a user

Delegates to Hyperliquid.Api.Info.IsVip.request/1.

Parameters

  • user - Required parameter

Returns

VIP status with tier and fee rates if applicable

@spec is_vip!(term()) :: struct()

Check VIP status for a user (bang variant)

Delegates to Hyperliquid.Api.Info.IsVip.request!/1.

Raises on error.

@spec l2_book(term()) :: {:ok, struct()} | {:error, term()}

Retrieve L2 order book snapshot for a coin

Delegates to Hyperliquid.Api.Info.L2Book.request/1.

Parameters

  • coin - Required parameter

Returns

Order book with bids/asks arrays containing price, size, and order count

@spec l2_book!(term()) :: struct()

Retrieve L2 order book snapshot for a coin (bang variant)

Delegates to Hyperliquid.Api.Info.L2Book.request!/1.

Raises on error.

@spec leading_vaults(term()) :: {:ok, struct()} | {:error, term()}

Retrieve leading vaults information

Delegates to Hyperliquid.Api.Info.LeadingVaults.request/1.

Parameters

  • user - Required parameter

Returns

Top performing vaults with their details

@spec leading_vaults!(term()) :: struct()

Retrieve leading vaults information (bang variant)

Delegates to Hyperliquid.Api.Info.LeadingVaults.request!/1.

Raises on error.

@spec liquidatable() :: {:ok, struct()} | {:error, term()}

Retrieve liquidatable positions

Delegates to Hyperliquid.Api.Info.Liquidatable.request/0.

Returns

List of positions that can be liquidated

Examples

{:ok, result} = liquidatable()
@spec liquidatable!() :: struct()

Retrieve liquidatable positions (bang variant)

Delegates to Hyperliquid.Api.Info.Liquidatable.request!/0.

Raises on error.

@spec margin_table(term()) :: {:ok, struct()} | {:error, term()}

Retrieve margin table details

Delegates to Hyperliquid.Api.Info.MarginTable.request/1.

Parameters

  • id - Required parameter

Returns

Margin requirements and leverage tiers

@spec margin_table!(term()) :: struct()

Retrieve margin table details (bang variant)

Delegates to Hyperliquid.Api.Info.MarginTable.request!/1.

Raises on error.

Link to this function

max_builder_fee(user, builder)

@spec max_builder_fee(term(), term()) :: {:ok, struct()} | {:error, term()}

Retrieve maximum builder fee for a user

Delegates to Hyperliquid.Api.Info.MaxBuilderFee.request/2.

Parameters

  • user - Required parameter
  • builder - Required parameter

Returns

Maximum fee a builder can charge

Link to this function

max_builder_fee!(user, builder)

@spec max_builder_fee!(term(), term()) :: struct()

Retrieve maximum builder fee for a user (bang variant)

Delegates to Hyperliquid.Api.Info.MaxBuilderFee.request!/2.

Raises on error.

@spec max_market_order_ntls() :: {:ok, struct()} | {:error, term()}

Retrieve maximum market order notional values

Delegates to Hyperliquid.Api.Info.MaxMarketOrderNtls.request/0.

Returns

Max notional for market orders per coin

Examples

{:ok, result} = max_market_order_ntls()
Link to this function

max_market_order_ntls!()

@spec max_market_order_ntls!() :: struct()

Retrieve maximum market order notional values (bang variant)

Delegates to Hyperliquid.Api.Info.MaxMarketOrderNtls.request!/0.

Raises on error.

@spec meta() :: {:ok, struct()} | {:error, term()}

Retrieve perpetuals metadata (universe and margin tables)

Delegates to Hyperliquid.Api.Info.Meta.request/0.

Returns

Meta struct with universe, margin tables, and collateral token

Examples

{:ok, result} = meta()
@spec meta!() :: struct()

Retrieve perpetuals metadata (universe and margin tables) (bang variant)

Delegates to Hyperliquid.Api.Info.Meta.request!/0.

Raises on error.

@spec meta_and_asset_ctxs() :: {:ok, struct()} | {:error, term()}

Retrieve perpetuals metadata and asset contexts

Delegates to Hyperliquid.Api.Info.MetaAndAssetCtxs.request/0.

Returns

Metadata and context for all perpetual assets

Examples

{:ok, result} = meta_and_asset_ctxs()
@spec meta_and_asset_ctxs!() :: struct()

Retrieve perpetuals metadata and asset contexts (bang variant)

Delegates to Hyperliquid.Api.Info.MetaAndAssetCtxs.request!/0.

Raises on error.

@spec open_orders(term()) :: {:ok, struct()} | {:error, term()}

Retrieve a user's open orders

Delegates to Hyperliquid.Api.Info.OpenOrders.request/1.

Parameters

  • user - Required parameter

Returns

OpenOrders struct with list of open orders

@spec open_orders!(term()) :: struct()

Retrieve a user's open orders (bang variant)

Delegates to Hyperliquid.Api.Info.OpenOrders.request!/1.

Raises on error.

@spec order_status(term(), term()) :: {:ok, struct()} | {:error, term()}

Query order status by OID or CLOID

Delegates to Hyperliquid.Api.Info.OrderStatus.request/2.

Parameters

  • user - Required parameter
  • oid - Required parameter

Returns

Detailed order status information

Link to this function

order_status!(user, oid)

@spec order_status!(term(), term()) :: struct()

Query order status by OID or CLOID (bang variant)

Delegates to Hyperliquid.Api.Info.OrderStatus.request!/2.

Raises on error.

Link to this function

perp_deploy_auction_status()

@spec perp_deploy_auction_status() :: {:ok, struct()} | {:error, term()}

Retrieve perpetual deployment auction status

Delegates to Hyperliquid.Api.Info.PerpDeployAuctionStatus.request/0.

Returns

Current gas auction information for deploying new perpetuals

Examples

{:ok, result} = perp_deploy_auction_status()
Link to this function

perp_deploy_auction_status!()

@spec perp_deploy_auction_status!() :: struct()

Retrieve perpetual deployment auction status (bang variant)

Delegates to Hyperliquid.Api.Info.PerpDeployAuctionStatus.request!/0.

Raises on error.

@spec perp_dex_limits(term()) :: {:ok, struct()} | {:error, term()}

Retrieve perpetual DEX limits

Delegates to Hyperliquid.Api.Info.PerpDexLimits.request/1.

Parameters

  • dex - Required parameter

Returns

Caps and limits configured for a specific DEX

@spec perp_dex_limits!(term()) :: struct()

Retrieve perpetual DEX limits (bang variant)

Delegates to Hyperliquid.Api.Info.PerpDexLimits.request!/1.

Raises on error.

@spec perp_dexs() :: {:ok, struct()} | {:error, term()}

Retrieve all perpetual DEXs

Delegates to Hyperliquid.Api.Info.PerpDexs.request/0.

Returns

Information about all deployed perpetual DEXs

Examples

{:ok, result} = perp_dexs()
@spec perp_dexs!() :: struct()

Retrieve all perpetual DEXs (bang variant)

Delegates to Hyperliquid.Api.Info.PerpDexs.request!/0.

Raises on error.

Link to this function

perps_at_open_interest_cap()

@spec perps_at_open_interest_cap() :: {:ok, struct()} | {:error, term()}

Retrieve perpetuals at open interest cap

Delegates to Hyperliquid.Api.Info.PerpsAtOpenInterestCap.request/0.

Returns

Array of coin symbols at their maximum open interest

Examples

{:ok, result} = perps_at_open_interest_cap()
Link to this function

perps_at_open_interest_cap!()

@spec perps_at_open_interest_cap!() :: struct()

Retrieve perpetuals at open interest cap (bang variant)

Delegates to Hyperliquid.Api.Info.PerpsAtOpenInterestCap.request!/0.

Raises on error.

@spec portfolio(term()) :: {:ok, struct()} | {:error, term()}

Retrieve user portfolio performance data

Delegates to Hyperliquid.Api.Info.Portfolio.request/1.

Parameters

  • user - Required parameter

Returns

Historical account value, PnL, and volume data

@spec portfolio!(term()) :: struct()

Retrieve user portfolio performance data (bang variant)

Delegates to Hyperliquid.Api.Info.Portfolio.request!/1.

Raises on error.

Link to this function

pre_transfer_check(user, source)

@spec pre_transfer_check(term(), term()) :: {:ok, struct()} | {:error, term()}

Check user existence before transfer

Delegates to Hyperliquid.Api.Info.PreTransferCheck.request/2.

Parameters

  • user - Required parameter
  • source - Required parameter

Returns

User existence and sanction status

Link to this function

pre_transfer_check!(user, source)

@spec pre_transfer_check!(term(), term()) :: struct()

Check user existence before transfer (bang variant)

Delegates to Hyperliquid.Api.Info.PreTransferCheck.request!/2.

Raises on error.

@spec predicted_fundings() :: {:ok, struct()} | {:error, term()}

Retrieve predicted funding rates for perpetuals

Delegates to Hyperliquid.Api.Info.PredictedFundings.request/0.

Returns

Funding rate predictions across different venues

Examples

{:ok, result} = predicted_fundings()
@spec predicted_fundings!() :: struct()

Retrieve predicted funding rates for perpetuals (bang variant)

Delegates to Hyperliquid.Api.Info.PredictedFundings.request!/0.

Raises on error.

@spec recent_trades(term()) :: {:ok, struct()} | {:error, term()}

Retrieve recent trades for a coin

Delegates to Hyperliquid.Api.Info.RecentTrades.request/1.

Parameters

  • coin - Required parameter

Returns

List of recent trades with price, size, side, and timestamp

@spec recent_trades!(term()) :: struct()

Retrieve recent trades for a coin (bang variant)

Delegates to Hyperliquid.Api.Info.RecentTrades.request!/1.

Raises on error.

@spec referral(term()) :: {:ok, struct()} | {:error, term()}

Retrieve referral information for a user

Delegates to Hyperliquid.Api.Info.Referral.request/1.

Parameters

  • user - Required parameter

Returns

Referral stats, rewards, and referrer state

@spec referral!(term()) :: struct()

Retrieve referral information for a user (bang variant)

Delegates to Hyperliquid.Api.Info.Referral.request!/1.

Raises on error.

Link to this function

spot_clearinghouse_state(user)

@spec spot_clearinghouse_state(term()) :: {:ok, struct()} | {:error, term()}

Retrieve a user's spot token balances

Delegates to Hyperliquid.Api.Info.SpotClearinghouseState.request/1.

Parameters

  • user - Required parameter

Returns

Spot clearinghouse state with balances and escrows

Link to this function

spot_clearinghouse_state!(user)

@spec spot_clearinghouse_state!(term()) :: struct()

Retrieve a user's spot token balances (bang variant)

Delegates to Hyperliquid.Api.Info.SpotClearinghouseState.request!/1.

Raises on error.

@spec spot_deploy_state(term()) :: {:ok, struct()} | {:error, term()}

Retrieve spot token deployment state for user

Delegates to Hyperliquid.Api.Info.SpotDeployState.request/1.

Parameters

  • user - Required parameter

Returns

Deployment status for spot tokens

Link to this function

spot_deploy_state!(user)

@spec spot_deploy_state!(term()) :: struct()

Retrieve spot token deployment state for user (bang variant)

Delegates to Hyperliquid.Api.Info.SpotDeployState.request!/1.

Raises on error.

@spec spot_meta() :: {:ok, struct()} | {:error, term()}

Retrieve spot asset metadata

Delegates to Hyperliquid.Api.Info.SpotMeta.request/0.

Returns

Metadata for spot trading universe and tokens

Examples

{:ok, result} = spot_meta()
@spec spot_meta!() :: struct()

Retrieve spot asset metadata (bang variant)

Delegates to Hyperliquid.Api.Info.SpotMeta.request!/0.

Raises on error.

Link to this function

spot_meta_and_asset_ctxs()

@spec spot_meta_and_asset_ctxs() :: {:ok, struct()} | {:error, term()}

Retrieve spot metadata and asset contexts

Delegates to Hyperliquid.Api.Info.SpotMetaAndAssetCtxs.request/0.

Returns

Metadata and context for all spot assets

Examples

{:ok, result} = spot_meta_and_asset_ctxs()
Link to this function

spot_meta_and_asset_ctxs!()

@spec spot_meta_and_asset_ctxs!() :: struct()

Retrieve spot metadata and asset contexts (bang variant)

Delegates to Hyperliquid.Api.Info.SpotMetaAndAssetCtxs.request!/0.

Raises on error.

Link to this function

spot_pair_deploy_auction_status()

@spec spot_pair_deploy_auction_status() :: {:ok, struct()} | {:error, term()}

Retrieve spot pair deployment auction status

Delegates to Hyperliquid.Api.Info.SpotPairDeployAuctionStatus.request/0.

Returns

Auction status for deploying new spot pairs

Examples

{:ok, result} = spot_pair_deploy_auction_status()
Link to this function

spot_pair_deploy_auction_status!()

@spec spot_pair_deploy_auction_status!() :: struct()

Retrieve spot pair deployment auction status (bang variant)

Delegates to Hyperliquid.Api.Info.SpotPairDeployAuctionStatus.request!/0.

Raises on error.

@spec sub_accounts2(term()) :: {:ok, struct()} | {:error, term()}

Retrieve extended sub-accounts information

Delegates to Hyperliquid.Api.Info.SubAccounts2.request/1.

Parameters

  • user - Required parameter

Returns

Sub-accounts with additional details like balances

@spec sub_accounts2!(term()) :: struct()

Retrieve extended sub-accounts information (bang variant)

Delegates to Hyperliquid.Api.Info.SubAccounts2.request!/1.

Raises on error.

@spec sub_accounts(term()) :: {:ok, struct()} | {:error, term()}

Retrieve user's sub-accounts

Delegates to Hyperliquid.Api.Info.SubAccounts.request/1.

Parameters

  • user - Required parameter

Returns

List of sub-accounts for a user

@spec sub_accounts!(term()) :: struct()

Retrieve user's sub-accounts (bang variant)

Delegates to Hyperliquid.Api.Info.SubAccounts.request!/1.

Raises on error.

@spec token_details(term()) :: {:ok, struct()} | {:error, term()}

Retrieve token details

Delegates to Hyperliquid.Api.Info.TokenDetails.request/1.

Parameters

  • tokenId - Required parameter

Returns

Detailed information about a specific token

@spec token_details!(term()) :: struct()

Retrieve token details (bang variant)

Delegates to Hyperliquid.Api.Info.TokenDetails.request!/1.

Raises on error.

@spec twap_history(term()) :: {:ok, struct()} | {:error, term()}

Retrieve user's TWAP order history

Delegates to Hyperliquid.Api.Info.TwapHistory.request/1.

Parameters

  • user - Required parameter

Returns

Historical TWAP orders

@spec twap_history!(term()) :: struct()

Retrieve user's TWAP order history (bang variant)

Delegates to Hyperliquid.Api.Info.TwapHistory.request!/1.

Raises on error.

Link to this function

user_dex_abstraction(user)

@spec user_dex_abstraction(term()) :: {:ok, struct()} | {:error, term()}

Retrieve user DEX abstraction settings

Delegates to Hyperliquid.Api.Info.UserDexAbstraction.request/1.

Parameters

  • user - Required parameter

Returns

DEX abstraction configuration for a user

Link to this function

user_dex_abstraction!(user)

@spec user_dex_abstraction!(term()) :: struct()

Retrieve user DEX abstraction settings (bang variant)

Delegates to Hyperliquid.Api.Info.UserDexAbstraction.request!/1.

Raises on error.

@spec user_fees(term()) :: {:ok, struct()} | {:error, term()}

Retrieve user's trading fee rates

Delegates to Hyperliquid.Api.Info.UserFees.request/1.

Parameters

  • user - Required parameter

Returns

Maker and taker fee rates

@spec user_fees!(term()) :: struct()

Retrieve user's trading fee rates (bang variant)

Delegates to Hyperliquid.Api.Info.UserFees.request!/1.

Raises on error.

@spec user_fills(term()) :: {:ok, struct()} | {:error, term()}

Retrieve a user's trade fills

Delegates to Hyperliquid.Api.Info.UserFills.request/1.

Parameters

  • user - Required parameter

Returns

UserFills struct with list of executed trades

@spec user_fills!(term()) :: struct()

Retrieve a user's trade fills (bang variant)

Delegates to Hyperliquid.Api.Info.UserFills.request!/1.

Raises on error.

Link to this function

user_fills_by_time(user, startTime, opts \\ [])

@spec user_fills_by_time(term(), term(), keyword()) ::
  {:ok, struct()} | {:error, term()}

Retrieve user's trade fills filtered by time range

Delegates to Hyperliquid.Api.Info.UserFillsByTime.request/3.

Parameters

  • user - Required parameter
  • startTime - Required parameter
  • opts - Optional parameters: [:endTime, :aggregateByTime]

Returns

List of user fills within specified time range

Link to this function

user_fills_by_time!(user, startTime, opts \\ [])

@spec user_fills_by_time!(term(), term(), keyword()) :: struct()

Retrieve user's trade fills filtered by time range (bang variant)

Delegates to Hyperliquid.Api.Info.UserFillsByTime.request!/3.

Raises on error.

Link to this function

user_non_funding_ledger_updates(user, start_time)

@spec user_non_funding_ledger_updates(term(), term()) ::
  {:ok, struct()} | {:error, term()}

Retrieve user's non-funding ledger updates

Delegates to Hyperliquid.Api.Info.UserNonFundingLedgerUpdates.request/2.

Parameters

  • user - Required parameter
  • start_time - Required parameter

Returns

Deposits, withdrawals, transfers, and other non-funding ledger entries

Link to this function

user_non_funding_ledger_updates!(user, start_time)

@spec user_non_funding_ledger_updates!(term(), term()) :: struct()

Retrieve user's non-funding ledger updates (bang variant)

Delegates to Hyperliquid.Api.Info.UserNonFundingLedgerUpdates.request!/2.

Raises on error.

@spec user_rate_limit(term()) :: {:ok, struct()} | {:error, term()}

Query user rate limit status

Delegates to Hyperliquid.Api.Info.UserRateLimit.request/1.

Parameters

  • user - Required parameter

Returns

UserRateLimit with usage and cap

@spec user_rate_limit!(term()) :: struct()

Query user rate limit status (bang variant)

Delegates to Hyperliquid.Api.Info.UserRateLimit.request!/1.

Raises on error.

@spec user_role(term()) :: {:ok, struct()} | {:error, term()}

Retrieve user role information

Delegates to Hyperliquid.Api.Info.UserRole.request/1.

Parameters

  • user - Required parameter

Returns

User's role and permissions

@spec user_role!(term()) :: struct()

Retrieve user role information (bang variant)

Delegates to Hyperliquid.Api.Info.UserRole.request!/1.

Raises on error.

Link to this function

user_to_multi_sig_signers(user)

@spec user_to_multi_sig_signers(term()) :: {:ok, struct()} | {:error, term()}

Retrieve multi-sig signers for a user

Delegates to Hyperliquid.Api.Info.UserToMultiSigSigners.request/1.

Parameters

  • user - Required parameter

Returns

List of signers for multi-sig wallets

Link to this function

user_to_multi_sig_signers!(user)

@spec user_to_multi_sig_signers!(term()) :: struct()

Retrieve multi-sig signers for a user (bang variant)

Delegates to Hyperliquid.Api.Info.UserToMultiSigSigners.request!/1.

Raises on error.

Link to this function

user_twap_slice_fills(user)

@spec user_twap_slice_fills(term()) :: {:ok, struct()} | {:error, term()}

Retrieve user's TWAP slice fills

Delegates to Hyperliquid.Api.Info.UserTwapSliceFills.request/1.

Parameters

  • user - Required parameter

Returns

Individual slice fills from TWAP orders

Link to this function

user_twap_slice_fills!(user)

@spec user_twap_slice_fills!(term()) :: struct()

Retrieve user's TWAP slice fills (bang variant)

Delegates to Hyperliquid.Api.Info.UserTwapSliceFills.request!/1.

Raises on error.

Link to this function

user_twap_slice_fills_by_time(user, startTime, opts \\ [])

@spec user_twap_slice_fills_by_time(term(), term(), keyword()) ::
  {:ok, struct()} | {:error, term()}

Retrieve user's TWAP slice fills filtered by time

Delegates to Hyperliquid.Api.Info.UserTwapSliceFillsByTime.request/3.

Parameters

  • user - Required parameter
  • startTime - Required parameter
  • opts - Optional parameters: [:endTime, :aggregateByTime]

Returns

Individual slice fills from TWAP orders within time range

Link to this function

user_twap_slice_fills_by_time!(user, startTime, opts \\ [])

@spec user_twap_slice_fills_by_time!(term(), term(), keyword()) :: struct()

Retrieve user's TWAP slice fills filtered by time (bang variant)

Delegates to Hyperliquid.Api.Info.UserTwapSliceFillsByTime.request!/3.

Raises on error.

Link to this function

user_vault_equities(user)

@spec user_vault_equities(term()) :: {:ok, struct()} | {:error, term()}

Retrieve user's vault equity positions

Delegates to Hyperliquid.Api.Info.UserVaultEquities.request/1.

Parameters

  • user - Required parameter

Returns

Equity positions in vaults for a user

Link to this function

user_vault_equities!(user)

@spec user_vault_equities!(term()) :: struct()

Retrieve user's vault equity positions (bang variant)

Delegates to Hyperliquid.Api.Info.UserVaultEquities.request!/1.

Raises on error.

@spec validator_l1_votes() :: {:ok, struct()} | {:error, term()}

Retrieve validator L1 voting information

Delegates to Hyperliquid.Api.Info.ValidatorL1Votes.request/0.

Returns

L1 voting information for validators

Examples

{:ok, result} = validator_l1_votes()
@spec validator_l1_votes!() :: struct()

Retrieve validator L1 voting information (bang variant)

Delegates to Hyperliquid.Api.Info.ValidatorL1Votes.request!/0.

Raises on error.

@spec validator_summaries() :: {:ok, struct()} | {:error, term()}

Retrieve validator summaries

Delegates to Hyperliquid.Api.Info.ValidatorSummaries.request/0.

Returns

Summary information for all validators

Examples

{:ok, result} = validator_summaries()
@spec validator_summaries!() :: struct()

Retrieve validator summaries (bang variant)

Delegates to Hyperliquid.Api.Info.ValidatorSummaries.request!/0.

Raises on error.

Link to this function

vault_details(vaultAddress, opts \\ [])

@spec vault_details(
  term(),
  keyword()
) :: {:ok, struct()} | {:error, term()}

Retrieve detailed vault information

Delegates to Hyperliquid.Api.Info.VaultDetails.request/2.

Parameters

  • vaultAddress - Required parameter
  • opts - Optional parameters: [:user]

Returns

Comprehensive details about a specific vault

Link to this function

vault_details!(vaultAddress, opts \\ [])

@spec vault_details!(
  term(),
  keyword()
) :: struct()

Retrieve detailed vault information (bang variant)

Delegates to Hyperliquid.Api.Info.VaultDetails.request!/2.

Raises on error.

@spec vault_summaries() :: {:ok, struct()} | {:error, term()}

Retrieve vault summaries

Delegates to Hyperliquid.Api.Info.VaultSummaries.request/0.

Returns

Summary information for all vaults

Examples

{:ok, result} = vault_summaries()
@spec vault_summaries!() :: struct()

Retrieve vault summaries (bang variant)

Delegates to Hyperliquid.Api.Info.VaultSummaries.request!/0.

Raises on error.