View Source Hyperliquid.Api.Info.Liquidatable (hyperliquid v0.2.2)

Liquidatable positions.

Returns list of positions that can be liquidated.

See: https://hyperliquid.gitbook.io/hyperliquid-docs/for-developers/api/info-endpoint

Usage

{:ok, liquidatable} = Liquidatable.request()
btc_positions = Liquidatable.by_coin(liquidatable, "BTC")

Summary

Functions

Returns metadata about this endpoint.

Returns postgres table configurations (multi-table support).

Returns storage configuration for this endpoint.

Build a cache key from response data using the configured pattern. Returns nil if cache is not enabled or no pattern configured.

Build the request payload.

Get positions by coin.

Returns true if cache storage is enabled.

Returns the cache TTL if configured.

Creates a changeset for liquidatable data.

Get total count.

Fetch is an alias for request when no storage is configured.

Parse and validate the API response.

Returns true if postgres storage is enabled.

Returns the postgres table name if configured (primary table for legacy support).

Returns the upsert config for postgres (primary table for legacy support).

Get the rate limit cost for this endpoint.

Make the API request and parse the response.

Make the API request, raising on error.

Make the API request and return the raw response map (no key transformation).

Make the API request returning raw map, raising on error.

Returns true if any storage backend is enabled.

Types

@type t() :: %Hyperliquid.Api.Info.Liquidatable{positions: [Position.t()]}

Functions

Returns metadata about this endpoint.

Example

iex> Hyperliquid.Api.Info.Liquidatable.__endpoint_info__()
%{
  endpoint: "liquidatable",
  type: :info,
  rate_limit_cost: 1,
  params: [],
  optional_params: [],
  doc: "Retrieve liquidatable positions",
  returns: "List of positions that can be liquidated"
}

Returns postgres table configurations (multi-table support).

Returns storage configuration for this endpoint.

Build a cache key from response data using the configured pattern. Returns nil if cache is not enabled or no pattern configured.

@spec build_request() :: map()

Build the request payload.

Link to this function

by_coin(liquidatable, coin)

@spec by_coin(t(), String.t()) :: [map()]

Get positions by coin.

Returns true if cache storage is enabled.

Returns the cache TTL if configured.

Link to this function

changeset(liquidatable \\ %__MODULE__{}, attrs)

@spec changeset(t(), map()) :: Ecto.Changeset.t()

Creates a changeset for liquidatable data.

@spec count(t()) :: non_neg_integer()

Get total count.

Fetch is an alias for request when no storage is configured.

@spec parse_response(map()) :: {:ok, t()} | {:error, term()}

Parse and validate the API response.

Returns true if postgres storage is enabled.

Returns the postgres table name if configured (primary table for legacy support).

Link to this function

postgres_upsert_config()

Returns the upsert config for postgres (primary table for legacy support).

@spec rate_limit_cost() :: non_neg_integer()

Get the rate limit cost for this endpoint.

@spec request() :: {:ok, t()} | {:error, term()}

Make the API request and parse the response.

@spec request!() :: t()

Make the API request, raising on error.

@spec request_raw() :: {:ok, map()} | {:error, term()}

Make the API request and return the raw response map (no key transformation).

@spec request_raw!() :: map()

Make the API request returning raw map, raising on error.

Returns true if any storage backend is enabled.