View Source Hyperliquid.Api.Info.MaxBuilderFee (hyperliquid v0.2.2)
Maximum builder fee for a user.
Returns the max fee a builder can charge.
See: https://hyperliquid.gitbook.io/hyperliquid-docs/for-developers/api/info-endpoint
Summary
Functions
Returns metadata about this endpoint.
Returns postgres table configurations (multi-table support).
Returns storage configuration for this endpoint.
Build a cache key from response data using the configured pattern.
Returns nil if cache is not enabled or no pattern configured.
Build the request payload.
Returns true if cache storage is enabled.
Returns the cache TTL if configured.
Creates a changeset for max builder fee data.
Get fee value.
Fetch is an alias for request when no storage is configured.
Parse and validate the API response.
Returns true if postgres storage is enabled.
Returns the postgres table name if configured (primary table for legacy support).
Returns the upsert config for postgres (primary table for legacy support).
Get the rate limit cost for this endpoint.
Make the API request and parse the response.
Make the API request, raising on error.
Make the API request and return the raw response map (no key transformation).
Make the API request returning raw map, raising on error.
Returns true if any storage backend is enabled.
Types
@type t() :: %Hyperliquid.Api.Info.MaxBuilderFee{max_fee: float()}
Functions
Returns metadata about this endpoint.
Example
iex> Hyperliquid.Api.Info.MaxBuilderFee.__endpoint_info__()
%{
endpoint: "maxBuilderFee",
type: :info,
rate_limit_cost: 1,
params: [:user, :builder],
optional_params: [],
doc: "Retrieve maximum builder fee for a user",
returns: "Maximum fee a builder can charge"
}
Returns postgres table configurations (multi-table support).
Returns storage configuration for this endpoint.
Build a cache key from response data using the configured pattern.
Returns nil if cache is not enabled or no pattern configured.
Build the request payload.
Returns true if cache storage is enabled.
Returns the cache TTL if configured.
@spec changeset(t(), map()) :: Ecto.Changeset.t()
Creates a changeset for max builder fee data.
Get fee value.
Fetch is an alias for request when no storage is configured.
@spec parse_response(number()) :: {:ok, t()} | {:error, term()}
@spec parse_response(map()) :: {:ok, t()} | {:error, term()}
Parse and validate the API response.
Returns true if postgres storage is enabled.
Returns the postgres table name if configured (primary table for legacy support).
Returns the upsert config for postgres (primary table for legacy support).
@spec rate_limit_cost() :: non_neg_integer()
Get the rate limit cost for this endpoint.
Make the API request and parse the response.
Make the API request, raising on error.
Make the API request and return the raw response map (no key transformation).
Make the API request returning raw map, raising on error.
Returns true if any storage backend is enabled.