View Source Hyperliquid.Api.Info.PerpDexLimits (hyperliquid v0.2.2)
Limits for a builder-deployed perpetual DEX.
Returns the various caps and limits configured for a specific DEX.
See: https://hyperliquid.gitbook.io/hyperliquid-docs/for-developers/api/info-endpoint/perpetuals
Summary
Functions
Returns metadata about this endpoint.
Returns postgres table configurations (multi-table support).
Returns storage configuration for this endpoint.
Build a cache key from response data using the configured pattern.
Returns nil if cache is not enabled or no pattern configured.
Build the request payload.
Returns true if cache storage is enabled.
Returns the cache TTL if configured.
Creates a changeset for perp dex limits data.
Get all coins with specific OI caps.
Fetch is an alias for request when no storage is configured.
Get the OI cap for a specific coin.
Parse and validate the API response.
Returns true if postgres storage is enabled.
Returns the postgres table name if configured (primary table for legacy support).
Returns the upsert config for postgres (primary table for legacy support).
Get the rate limit cost for this endpoint.
Make the API request and parse the response.
Make the API request, raising on error.
Make the API request and return the raw response map (no key transformation).
Make the API request returning raw map, raising on error.
Returns true if any storage backend is enabled.
Types
Functions
Returns metadata about this endpoint.
Example
iex> Hyperliquid.Api.Info.PerpDexLimits.__endpoint_info__()
%{
endpoint: "perpDexLimits",
type: :info,
rate_limit_cost: 1,
params: [:dex],
optional_params: [],
doc: "Retrieve perpetual DEX limits",
returns: "Caps and limits configured for a specific DEX"
}
Returns postgres table configurations (multi-table support).
Returns storage configuration for this endpoint.
Build a cache key from response data using the configured pattern.
Returns nil if cache is not enabled or no pattern configured.
Build the request payload.
Returns true if cache storage is enabled.
Returns the cache TTL if configured.
@spec changeset(t(), map()) :: Ecto.Changeset.t()
Creates a changeset for perp dex limits data.
Parameters
limits: The limits structattrs: Map of attributes to validate
Returns
Ecto.Changeset.t()
Get all coins with specific OI caps.
Parameters
limits: The limits struct
Returns
- List of coin symbols
Fetch is an alias for request when no storage is configured.
Get the OI cap for a specific coin.
Parameters
limits: The limits structcoin: Coin symbol
Returns
{:ok, String.t()}if found{:error, :not_found}if not found
Parse and validate the API response.
Returns true if postgres storage is enabled.
Returns the postgres table name if configured (primary table for legacy support).
Returns the upsert config for postgres (primary table for legacy support).
@spec rate_limit_cost() :: non_neg_integer()
Get the rate limit cost for this endpoint.
Make the API request and parse the response.
Make the API request, raising on error.
Make the API request and return the raw response map (no key transformation).
Make the API request returning raw map, raising on error.
Returns true if any storage backend is enabled.